#ifndef ___RB_GSL_CONFIG_H___
#define ___RB_GSL_CONFIG_H___

#ifndef GSL_VERSION
#define GSL_VERSION "1.6"
#endif
#ifndef GSL_0_9_4_LATER
#define GSL_0_9_4_LATER
#endif
#ifndef GSL_1_0_LATER
#define GSL_1_0_LATER
#endif
#ifndef GSL_1_1_LATER
#define GSL_1_1_LATER
#endif
#ifndef GSL_1_1_1_LATER
#define GSL_1_1_1_LATER
#endif
#ifndef GSL_1_2_LATER
#define GSL_1_2_LATER
#endif
#ifndef GSL_1_3_LATER
#define GSL_1_3_LATER
#endif
#ifndef GSL_1_4_LATER
#define GSL_1_4_LATER
#endif
#ifndef GSL_1_4_9_LATER
#define GSL_1_4_9_LATER
#endif
#ifndef GSL_1_6_LATER
#define GSL_1_6_LATER
#endif
#ifndef RUBY_GSL_VERSION
#define RUBY_GSL_VERSION "1.6.2-preview3"
#endif
#ifndef RUBY_1_8_LATER
#define RUBY_1_8_LATER
#endif
#ifndef HAVE_GNU_GRAPH
#define HAVE_GNU_GRAPH
#endif

#endif
